pub struct EphemeralSecret<T: Zeroize> { /* private fields */ }Expand description
Ephemeral secret that invokes explicit clearing on drop.
This type wraps a value and invokes its Zeroize implementation on drop.
It is useful for temporary secrets and intermediate cryptographic values,
subject to the module-level limits of best-effort software clearing.
Implementations
Sourceimpl<T: Zeroize> EphemeralSecret<T>
impl<T: Zeroize> EphemeralSecret<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consume the secret and return the inner value
Note: after calling this method, the caller owns the value and is responsible for invoking its clearing policy when appropriate.