Secret data types that invoke zeroization for owned storage
This module provides type-safe wrappers that invoke explicit clearing for initialized storage they own. Software zeroization cannot erase caller, compiler/register, allocator, swap, crash-dump, or already-freed copies.
Structs
- Ephemeral
Secret - Ephemeral secret that invokes explicit clearing on drop.
- Secret
Buffer - A fixed-size byte array that explicitly clears its owned storage on drop.
- Secret
Vec - Exact-size owned bytes whose initialized storage is explicitly cleared on drop.
- Zeroize
Guard - Guard type that invokes a value’s
Zeroizeimplementation when dropped.
Traits
- Secure
Zeroing Type - Trait for types that explicitly clear owned storage and preserve that behavior when cloned.