Module secret

Module secret 

Secret data types that invoke zeroization for owned storage

This module provides type-safe wrappers for sensitive data that ensure cleanup and zeroization when the data is no longer needed. Software zeroization cannot erase caller, compiler/register, or already-freed copies.

Structs

EphemeralSecret
Ephemeral secret that is automatically zeroized after use
SecretBuffer
Fixed-size secret buffer that guarantees zeroization
SecretVec
Variable-size secret vector that wipes storage it owns
ZeroizeGuard
Guard type that ensures a value is zeroized when dropped

Traits

SecureZeroingType
Trait for types that can be securely zeroed and cloned